@@ -3,7 +3,7 @@
 from pathlib import Path
 from typing import Any
 
-DOC_URL = "https://dmerejkowsky.github.io/tsrc/ref/formats/"
+DOC_URL = "https://dmerejkowsky.github.io/tsrc"
 
 
 class Error(Exception):
@@ -16,6 +16,9 @@ class Error(Exception):
     def __str__(self) -> str:
         return self.message
 
+    def __repr__(self) -> str:
+        return f"<{self.__class__.__name__}>"
+
 
 class InvalidConfig(Error):
     def __init__(self, config_path: Path, cause: Exception) -> None:
