@@ -18,7 +18,7 @@ the Task[T] interface
 
 ## Running tasks
 
-* If num_jobs is None, the SequentialExecutor is used,
+* If num_jobs is 1, the SequentialExecutor is used,
   otherwise the ParallelExecutor is used. The  `parallel` boolean
   attribute on the Task instances is set accordingly.
 * Both the SequentialExecutor and the ParallelExecutor will call
@@ -85,11 +85,11 @@ to print the summary, or an error message when relevant.
 
 import abc
 from concurrent.futures import ThreadPoolExecutor, as_completed
+from dataclasses import dataclass
 from pathlib import Path
 from threading import Lock
 from typing import Any, Dict, Generic, List, Optional, TypeVar
 
-import attr
 import cli_ui as ui
 
 from tsrc.errors import Error
@@ -103,12 +103,12 @@ class ExecutorFailed(Error):
     pass
 
 
-@attr.s
+@dataclass
 class Outcome:
     """The result of processing an item."""
 
-    error: Optional[Error] = attr.ib()
-    summary: Optional[str] = attr.ib()
+    error: Optional[Error]
+    summary: Optional[str]
 
     @classmethod
     def empty(cls) -> "Outcome":
@@ -319,9 +319,9 @@ class ParallelExecutor(Generic[T]):
 
 
 def process_items(
-    items: List[T], task: Task[T], *, num_jobs: Optional[int] = None
+    items: List[T], task: Task[T], *, num_jobs: int = 1
 ) -> OutcomeCollection:
-    if num_jobs:
+    if num_jobs > 1:
         res = process_items_parallel(items, task, num_jobs=num_jobs)
     else:
         res = process_items_sequence(items, task)
