@@ -18,6 +18,10 @@ class FileSystemOperation(metaclass=abc.ABCMeta):
     def perform(self, workspace_path: Path) -> None:
         pass
 
+    @abc.abstractmethod
+    def get_repo(self) -> str:
+        pass
+
 
 @dataclass(frozen=True)
 class Copy(FileSystemOperation):
@@ -25,6 +29,9 @@ class Copy(FileSystemOperation):
     src: str
     dest: str
 
+    def get_repo(self) -> str:
+        return self.repo
+
     def describe(self, workspace_path: Path) -> str:
         src_path = workspace_path / self.repo / self.src
         dest_path = workspace_path / self.dest
@@ -42,6 +49,9 @@ class Link(FileSystemOperation):
     source: str
     target: str
 
+    def get_repo(self) -> str:
+        return self.repo
+
     def describe(self, workspace_path: Path) -> str:
         source = workspace_path / self.source
         return f"Link {source} -> {self.target}"
