@@ -16,9 +16,11 @@ def test_apply_manifest_adds_new_repo(
     * Create a workspace using `tsrc init`
     * Copy the manifest file somewhere in the workspace
     * Create a new repo on the server
-    * Edit the copied manifest to contain the new repo
+    * Edit the copied manifest to contain the new repo, including
+      a file system copy
     * Run `tsrc apply-manifest /path/to/copied_manifest`
-    * Check that the new repo gets cloned
+    * Check that the new repo is cloned
+    * Check that the copy is performed
 
     """
     git_server.add_repo("foo")
@@ -29,18 +31,22 @@ def test_apply_manifest_adds_new_repo(
     shutil.copy(cloned_manifest_path, copied_manifest_path)
 
     bar_url = git_server.add_repo("bar", add_to_manifest=False)
-    add_repo_to_manifest(copied_manifest_path, "bar", bar_url)
+    git_server.push_file("bar", "src")
+    add_repo_to_manifest_with_copy(copied_manifest_path, "bar", bar_url)
 
     tsrc_cli.run("apply-manifest", str(copied_manifest_path))
 
     assert (workspace_path / "bar").exists(), "bar repo should have been cloned"
+    assert (
+        workspace_path / "dest"
+    ).exists(), "file system operations should have been performed"
 
 
-def add_repo_to_manifest(manifest_path: Path, dest: str, url: str) -> None:
+def add_repo_to_manifest_with_copy(manifest_path: Path, dest: str, url: str) -> None:
     yaml = ruamel.yaml.YAML()
     data = yaml.load(manifest_path.read_text())
     repos = data["repos"]
-    to_add = {"dest": dest, "url": url}
+    to_add = {"dest": dest, "url": url, "copy": [{"file": "src", "dest": "dest"}]}
     repos.append(to_add)
     with manifest_path.open("w") as fileobj:
         yaml.dump(data, fileobj)
