@@ -3,14 +3,15 @@ from pathlib import Path
 
 import pytest
 
-import tsrc.file_system
+from tsrc.errors import Error
+from tsrc.file_system import safe_link
 
 
 def test_can_create_symlink_when_source_does_not_exist(tmp_path: Path) -> None:
     source = tmp_path / "source"
     target = tmp_path / "target"
     target.touch()
-    tsrc.file_system.safe_link(source=source, target=target)
+    safe_link(source=source, target=target)
     assert source.exists()
     assert source.resolve() == target.resolve()
 
@@ -19,7 +20,7 @@ def test_can_create_symlink_pointing_to_directory(tmp_path: Path) -> None:
     source = tmp_path / "source"
     target = tmp_path / "target"
     target.mkdir(parents=True)
-    tsrc.file_system.safe_link(source=source, target=target)
+    safe_link(source=source, target=target)
 
     assert source.exists()
     assert source.resolve() == target.resolve()
@@ -29,8 +30,8 @@ def test_cannot_create_symlink_when_source_is_a_file(tmp_path: Path) -> None:
     source = tmp_path / "source"
     target = tmp_path / "target"
     source.touch()
-    with pytest.raises(tsrc.Error) as e:
-        tsrc.file_system.safe_link(source=source, target=target)
+    with pytest.raises(Error) as e:
+        safe_link(source=source, target=target)
     assert "is not a link" in e.value.message
 
 
@@ -41,7 +42,7 @@ def test_can_update_broken_symlink(tmp_path: Path) -> None:
 
     new_target = tmp_path / "new_target"
     new_target.touch()
-    tsrc.file_system.safe_link(source=source, target=new_target)
+    safe_link(source=source, target=new_target)
 
     assert source.exists()
     assert source.resolve() == new_target.resolve()
@@ -54,7 +55,7 @@ def test_can_update_existing_symlink(tmp_path: Path) -> None:
     os.symlink(target, source)
 
     new_target = tmp_path / "new_target"
-    tsrc.file_system.safe_link(source=source, target=new_target)
+    safe_link(source=source, target=new_target)
 
     new_target.touch()
     assert source.exists()
@@ -67,7 +68,7 @@ def test_do_nothing_if_symlink_has_the_correct_target(tmp_path: Path) -> None:
     target.touch()
     os.symlink(target, source)
 
-    tsrc.file_system.safe_link(source=source, target=target)
+    safe_link(source=source, target=target)
 
     assert source.exists()
     assert source.resolve() == target.resolve()
