@@ -1,8 +1,7 @@
 from pathlib import Path
-from typing import List, Optional, Tuple, cast  # noqa
 
-import tsrc
-import tsrc.manifest
+from tsrc.git import run_git
+from tsrc.manifest import Manifest, load_manifest
 
 
 class LocalManifest:
@@ -31,25 +30,21 @@ class LocalManifest:
         else:
             self._clone_manifest(url, branch=branch)
 
-    def get_manifest(self) -> tsrc.manifest.Manifest:
-        return tsrc.manifest.load(self.clone_path / "manifest.yml")
+    def get_manifest(self) -> Manifest:
+        return load_manifest(self.clone_path / "manifest.yml")
 
     def _reset_manifest_clone(self, url: str, *, branch: str) -> None:
-        tsrc.git.run(self.clone_path, "remote", "set-url", "origin", url)
-
-        tsrc.git.run(self.clone_path, "fetch")
-        tsrc.git.run(self.clone_path, "checkout", "-B", branch)
-        # fmt: off
-        tsrc.git.run(
-            self.clone_path, "branch", branch,
-            "--set-upstream-to", f"origin/{branch}"
+        run_git(self.clone_path, "remote", "set-url", "origin", url)
+        run_git(self.clone_path, "fetch")
+        run_git(self.clone_path, "checkout", "-B", branch)
+        run_git(
+            self.clone_path, "branch", branch, "--set-upstream-to", f"origin/{branch}"
         )
-        # fmt: on
         ref = f"origin/{branch}"
-        tsrc.git.run(self.clone_path, "reset", "--hard", ref)
+        run_git(self.clone_path, "reset", "--hard", ref)
 
     def _clone_manifest(self, url: str, *, branch: str) -> None:
         parent = self.clone_path.parent
         name = self.clone_path.name
         parent.mkdir(parents=True, exist_ok=True)
-        tsrc.git.run(self.clone_path.parent, "clone", url, "--branch", branch, name)
+        run_git(self.clone_path.parent, "clone", url, "--branch", branch, name)
